------------------------------------------------------------------------------
--
--  Xilinx, Inc. 2002                 www.xilinx.com
--
--  XAPP 224 - Data Recovery
--
------------------------------------------------------------------------------
--
--  File name :       top_v2_fast.v
--
--  Description :     Generic top level file to use data recovery module in a Virtex2,
-- 		      uses two dcms to generate two 90 degree phased clocks at up to 210 Mhz in a -5 .
--
--  Date - revision : May 21st 2006 - v 2.4
--
--  Author :          NJS
--
--  Disclaimer: LIMITED WARRANTY AND DISCLAMER. These designs are
--              provided to you "as is". Xilinx and its licensors make and you
--              receive no warranties or conditions, express, implied,
--              statutory or otherwise, and Xilinx specifically disclaims any
--              implied warranties of merchantability, non-infringement,or
--              fitness for a particular purpose. Xilinx does not warrant that
--              the functions contained in these designs will meet your
--              requirements, or that the operation of these designs will be
--              uninterrupted or error free, or that defects in the Designs
--              will be corrected. Furthermore, Xilinx does not warrantor
--              make any representations regarding use or the results of the
--              use of the designs in terms of correctness, accuracy,
--              reliability, or otherwise.
--
--              LIMITATION OF LIABILITY. In no event will Xilinx or its
--              licensors be liable for any loss of data, lost profits,cost
--              or procurement of substitute goods or services, or for any
--              special, incidental, consequential, or indirect damages
--              arising from the use or operation of the designs or
--              accompanying documentation, however caused and on any theory
--              of liability. This limitation will apply even if Xilinx
--              has been advised of the possibility of such damage. This
--              limitation shall apply not-withstanding the failure of the
--              essential purpose of any limited remedies herein.
--
--  Copyright  2002 Xilinx, Inc.
--  All rights reserved
--
------------------------------------------------------------------------------
--
library IEEE;
use IEEE.std_logic_1164.all;

library unisim ;
use unisim.vcomponents.all ;

entity top_v2_fast is port (
	clkin 	: in std_logic;				-- clock input
	rstin 	: in std_logic;				-- reset input
	datain 	: in std_logic;				-- data input
	dummy 	: out std_logic_vector(1 downto 0);	-- dummy output for recovered data
	dvalid 	: out std_logic_vector(1 downto 0);	-- recovered data valid when high
	locked	: out std_logic); 			-- DCMs locked
end top_v2_fast;

architecture arch_top_v2_fast of top_v2_fast is

-- Data recovery module
component data_recovery_virtex2_fast port (
	clk 	: in std_logic;
	clk90 	: in std_logic;
	data 	: in std_logic;
	rst 	: in std_logic;
	sdata 	: out std_logic_vector(1 downto 0) ;
	dv 	: out std_logic_vector(1 downto 0)) ; 
end component;

signal clk   	: std_logic;
signal low   	: std_logic;
signal clkdcm	: std_logic;
signal clkint	: std_logic;
signal clk90	: std_logic;
signal clk90dcm : std_logic;
signal dummyint : std_logic_vector(1 downto 0) ;
signal dvalidint: std_logic_vector(1 downto 0) ;
signal locked0  : std_logic ;
signal locked1  : std_logic ;

begin

Low <= '0' ;
locked <= locked0 and locked1 ;

dcm_0 : dcm 
generic map (
	CLKIN_PERIOD 		=> 2.5,
	DLL_FREQUENCY_MODE	=> "HIGH")
port map (
	clkin   => clkint,
	CLKFB   => clk,
	DSSEN 	=> low,
	PSINCDEC=> low,
	PSEN 	=> low,
	PSCLK 	=> low,
	RST     => rstin,
	CLK0    => clkdcm,
	CLK90   => open,
	CLK180  => open,
	CLK270  => open,
	CLK2X   => open,
	CLK2X180=> open,
	CLKDV   => open,
	CLKFX   => open,
	CLKFX180=> open,
	LOCKED  => locked0,
	PSDONE  => open,
	STATUS  => open);

dcm_1 : dcm 
generic map (
	CLKIN_PERIOD 		=> 2.5,
	CLKOUT_PHASE_SHIFT 	=> "FIXED",
	PHASE_SHIFT		=> 64,
	DLL_FREQUENCY_MODE	=> "HIGH")
port map (
	clkin   => clkint,
	CLKFB   => clk90,
	DSSEN 	=> low,
	PSINCDEC=> low,
	PSEN 	=> low,
	PSCLK 	=> low,
	RST     => rstin,
	CLK0    => clk90dcm,
	CLK90   => open,
	CLK180  => open,
	CLK270  => open,
	CLK2X   => open,
	CLK2X180=> open,
	CLKDV   => open,
	CLKFX   => open,
	CLKFX180=> open,
	LOCKED  => locked1,
	PSDONE  => open,
	STATUS  => open);
	
ibufg1 : ibufg port map(i => clkin, o => clkint );

bufg1  : bufg  port map(i => clkdcm, o => clk );

bufg2  : bufg  port map(i => clk90dcm, o => clk90 );
	
drmodule : data_recovery_virtex2_fast port map(
	data 	=> datain,
	rst   	=> rstin,
	clk   	=> clk,
	clk90 	=> clk90,
	sdata 	=> dummyint,
	dv 	=> dvalidint );
		
process (clk, rstin)
begin
if rstin = '1' then
	dummy <= "00" ;
	dvalid <= "00" ;
elsif clk'event and clk = '1' then
	dummy <= dummyint ;
	dvalid <= dvalidint ;
end if ;
end process ;
end arch_top_v2_fast;


